@@ -1,25 +1,27 @@
-import dask.dataframe as dd
-from dask import delayed
-from dask.dataframe.partitionquantiles import partition_quantiles
-
-from spatialpandas.geometry.base import _BaseCoordinateIndexer, GeometryDtype
-from spatialpandas.spatialindex import HilbertRtree
-from .geoseries import GeoSeries
-from .geodataframe import GeoDataFrame
-import dask
-from dask.dataframe.core import get_parallel_type
-from dask.dataframe.utils import make_meta, meta_nonempty, make_array_nonempty
-import pandas as pd
-import numpy as np
-import pyarrow.parquet as pq
-import pyarrow as pa
+import copy
+import json
 import os
 import uuid
-import json
-import copy
 from inspect import signature
+
+import numpy as np
+import pandas as pd
+import pyarrow as pa
+import pyarrow.parquet as pq
 from retrying import retry
 
+import dask
+import dask.dataframe as dd
+from dask import delayed
+from dask.dataframe.core import get_parallel_type
+from dask.dataframe.partitionquantiles import partition_quantiles
+from dask.dataframe.utils import make_array_nonempty, make_meta, meta_nonempty
+
+from .geodataframe import GeoDataFrame
+from .geometry.base import GeometryDtype, _BaseCoordinateIndexer
+from .geoseries import GeoSeries
+from .spatialindex import HilbertRtree
+
 
 class DaskGeoSeries(dd.Series):
     def __init__(self, dsk, name, meta, divisions, *args, **kwargs):
@@ -76,6 +78,12 @@ class DaskGeoSeries(dd.Series):
     def cx_partitions(self):
         return _DaskPartitionCoordinateIndexer(self, self.partition_sindex)
 
+    def build_sindex(self):
+        def build_sindex(series):
+            series.build_sindex()
+            return series
+        return self.map_partitions(build_sindex, meta=self._meta)
+
     def intersects_bounds(self, bounds):
         return self.map_partitions(lambda s: s.intersects_bounds(bounds))
 
@@ -515,6 +523,12 @@ class DaskGeoDataFrame(dd.DataFrame):
             new_series._partition_sindex = self._partition_sindex[new_series.name]
         return new_series
 
+    def build_sindex(self):
+        def build_sindex(df):
+            df.build_sindex()
+            return df
+        return self.map_partitions(build_sindex, meta=self._meta)
+
     def persist(self, **kwargs):
         return self._propagate_props_to_dataframe(
             super().persist(**kwargs)
